summaryrefslogtreecommitdiff
path: root/src/modules/clist
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/clist')
-rw-r--r--src/modules/clist/clc.cpp32
-rw-r--r--src/modules/clist/clistevents.cpp6
-rw-r--r--src/modules/clist/clistmenus.cpp2
-rw-r--r--src/modules/clist/clistmod.cpp6
-rw-r--r--src/modules/clist/clistsettings.cpp18
-rw-r--r--src/modules/clist/clisttray.cpp4
-rw-r--r--src/modules/clist/contacts.cpp2
7 files changed, 35 insertions, 35 deletions
diff --git a/src/modules/clist/clc.cpp b/src/modules/clist/clc.cpp
index 6e10794f1e..4f516367c4 100644
--- a/src/modules/clist/clc.cpp
+++ b/src/modules/clist/clc.cpp
@@ -80,49 +80,49 @@ static int ClcSettingChanged(WPARAM hContact, LPARAM lParam)
{
DBCONTACTWRITESETTING *cws = (DBCONTACTWRITESETTING *) lParam;
if (hContact == NULL) {
- if (!strcmp(cws->szModule, "CListGroups"))
+ if (!mir_strcmp(cws->szModule, "CListGroups"))
cli.pfnClcBroadcast(INTM_GROUPSCHANGED, hContact, lParam);
return 0;
}
- if (!strcmp(cws->szModule, "CList")) {
- if (!strcmp(cws->szSetting, "MyHandle")) {
+ if (!mir_strcmp(cws->szModule, "CList")) {
+ if (!mir_strcmp(cws->szSetting, "MyHandle")) {
cli.pfnInvalidateDisplayNameCacheEntry(hContact);
cli.pfnClcBroadcast(INTM_NAMECHANGED, hContact, lParam);
}
- else if (!strcmp(cws->szSetting, "Group"))
+ else if (!mir_strcmp(cws->szSetting, "Group"))
cli.pfnClcBroadcast(INTM_GROUPCHANGED, hContact, lParam);
- else if (!strcmp(cws->szSetting, "Hidden"))
+ else if (!mir_strcmp(cws->szSetting, "Hidden"))
cli.pfnClcBroadcast(INTM_HIDDENCHANGED, hContact, lParam);
- else if (!strcmp(cws->szSetting, "NotOnList"))
+ else if (!mir_strcmp(cws->szSetting, "NotOnList"))
cli.pfnClcBroadcast(INTM_NOTONLISTCHANGED, hContact, lParam);
- else if (!strcmp(cws->szSetting, "Status"))
+ else if (!mir_strcmp(cws->szSetting, "Status"))
cli.pfnClcBroadcast(INTM_INVALIDATE, 0, 0);
- else if (!strcmp(cws->szSetting, "NameOrder"))
+ else if (!mir_strcmp(cws->szSetting, "NameOrder"))
cli.pfnClcBroadcast(INTM_NAMEORDERCHANGED, 0, 0);
}
else {
char *szProto = GetContactProto(hContact);
if (szProto != NULL) {
- if (!strcmp(cws->szModule, "Protocol") && !strcmp(cws->szSetting, "p"))
+ if (!mir_strcmp(cws->szModule, "Protocol") && !mir_strcmp(cws->szSetting, "p"))
cli.pfnClcBroadcast(INTM_PROTOCHANGED, hContact, lParam);
// something is being written to a protocol module
- if (!strcmp(szProto, cws->szModule)) {
+ if (!mir_strcmp(szProto, cws->szModule)) {
// was a unique setting key written?
char *id = (char *) CallProtoServiceInt(NULL,szProto, PS_GETCAPS, PFLAG_UNIQUEIDSETTING, 0);
- if ((INT_PTR)id != CALLSERVICE_NOTFOUND && id != NULL && !strcmp(id, cws->szSetting))
+ if ((INT_PTR)id != CALLSERVICE_NOTFOUND && id != NULL && !mir_strcmp(id, cws->szSetting))
cli.pfnClcBroadcast(INTM_PROTOCHANGED, hContact, lParam);
}
}
- if (szProto == NULL || strcmp(szProto, cws->szModule))
+ if (szProto == NULL || mir_strcmp(szProto, cws->szModule))
return 0;
- if (!strcmp(cws->szSetting, "Nick") || !strcmp(cws->szSetting, "FirstName") || !strcmp(cws->szSetting, "e-mail")
- || !strcmp(cws->szSetting, "LastName") || !strcmp(cws->szSetting, "UIN"))
+ if (!mir_strcmp(cws->szSetting, "Nick") || !mir_strcmp(cws->szSetting, "FirstName") || !mir_strcmp(cws->szSetting, "e-mail")
+ || !mir_strcmp(cws->szSetting, "LastName") || !mir_strcmp(cws->szSetting, "UIN"))
cli.pfnClcBroadcast(INTM_NAMECHANGED, hContact, lParam);
- else if (!strcmp(cws->szSetting, "ApparentMode"))
+ else if (!mir_strcmp(cws->szSetting, "ApparentMode"))
cli.pfnClcBroadcast(INTM_APPARENTMODECHANGED, hContact, lParam);
- else if (!strcmp(cws->szSetting, "IdleTS"))
+ else if (!mir_strcmp(cws->szSetting, "IdleTS"))
cli.pfnClcBroadcast(INTM_IDLECHANGED, hContact, lParam);
}
return 0;
diff --git a/src/modules/clist/clistevents.cpp b/src/modules/clist/clistevents.cpp
index fae471f9b9..defb917c23 100644
--- a/src/modules/clist/clistevents.cpp
+++ b/src/modules/clist/clistevents.cpp
@@ -365,10 +365,10 @@ static int RemoveEventsForContact(WPARAM wParam, LPARAM)
static int CListEventSettingsChanged(WPARAM hContact, LPARAM lParam)
{
DBCONTACTWRITESETTING *cws = (DBCONTACTWRITESETTING*)lParam;
- if (hContact == NULL && cws && cws->szModule && cws->szSetting && strcmp(cws->szModule, "CList") == 0) {
- if (strcmp(cws->szSetting, "DisableTrayFlash") == 0)
+ if (hContact == NULL && cws && cws->szModule && cws->szSetting && mir_strcmp(cws->szModule, "CList") == 0) {
+ if (mir_strcmp(cws->szSetting, "DisableTrayFlash") == 0)
disableTrayFlash = (int)cws->value.bVal;
- else if (strcmp(cws->szSetting, "NoIconBlink") == 0)
+ else if (mir_strcmp(cws->szSetting, "NoIconBlink") == 0)
disableIconFlash = (int)cws->value.bVal;
}
return 0;
diff --git a/src/modules/clist/clistmenus.cpp b/src/modules/clist/clistmenus.cpp
index a50588813d..f63a86d5c0 100644
--- a/src/modules/clist/clistmenus.cpp
+++ b/src/modules/clist/clistmenus.cpp
@@ -346,7 +346,7 @@ INT_PTR ContactMenuCheckService(WPARAM wParam, LPARAM)
if (cmep->pszContactOwner != NULL) {
if (bcp->szProto == NULL) return FALSE;
- if (strcmp(cmep->pszContactOwner, bcp->szProto)) return FALSE;
+ if (mir_strcmp(cmep->pszContactOwner, bcp->szProto)) return FALSE;
}
TMO_MenuItem mi;
diff --git a/src/modules/clist/clistsettings.cpp b/src/modules/clist/clistsettings.cpp
index 5d748b175f..fee76ff9eb 100644
--- a/src/modules/clist/clistsettings.cpp
+++ b/src/modules/clist/clistsettings.cpp
@@ -220,14 +220,14 @@ int ContactSettingChanged(WPARAM hContact, LPARAM lParam)
DBVARIANT dbv;
dbv.pszVal = NULL;
if (!db_get(hContact, "Protocol", "p", &dbv)) {
- if (!strcmp(cws->szModule, dbv.pszVal)) {
+ if (!mir_strcmp(cws->szModule, dbv.pszVal)) {
cli.pfnInvalidateDisplayNameCacheEntry(hContact);
- if (!strcmp(cws->szSetting, "UIN") || !strcmp(cws->szSetting, "Nick") || !strcmp(cws->szSetting, "FirstName")
- || !strcmp(cws->szSetting, "LastName") || !strcmp(cws->szSetting, "e-mail"))
+ if (!mir_strcmp(cws->szSetting, "UIN") || !mir_strcmp(cws->szSetting, "Nick") || !mir_strcmp(cws->szSetting, "FirstName")
+ || !mir_strcmp(cws->szSetting, "LastName") || !mir_strcmp(cws->szSetting, "e-mail"))
{
CallService(MS_CLUI_CONTACTRENAMED, hContact, 0);
}
- else if (!strcmp(cws->szSetting, "Status")) {
+ else if (!mir_strcmp(cws->szSetting, "Status")) {
if (!db_get_b(hContact, "CList", "Hidden", 0)) {
if (db_get_b(NULL, "CList", "HideOffline", SETTING_HIDEOFFLINE_DEFAULT)) {
// User's state is changing, and we are hideOffline-ing
@@ -250,8 +250,8 @@ int ContactSettingChanged(WPARAM hContact, LPARAM lParam)
}
}
- if (!strcmp(cws->szModule, "CList")) {
- if (!strcmp(cws->szSetting, "Hidden")) {
+ if (!mir_strcmp(cws->szModule, "CList")) {
+ if (!mir_strcmp(cws->szSetting, "Hidden")) {
if (cws->value.type == DBVT_DELETED || cws->value.bVal == 0) {
char *szProto = GetContactProto(hContact);
cli.pfnChangeContactIcon(hContact, cli.pfnIconFromStatusMode(szProto, szProto == NULL ? ID_STATUS_OFFLINE : db_get_w(hContact, szProto, "Status", ID_STATUS_OFFLINE), hContact), 1);
@@ -259,12 +259,12 @@ int ContactSettingChanged(WPARAM hContact, LPARAM lParam)
else
CallService(MS_CLUI_CONTACTDELETED, hContact, 0);
}
- if (!strcmp(cws->szSetting, "MyHandle"))
+ if (!mir_strcmp(cws->szSetting, "MyHandle"))
cli.pfnInvalidateDisplayNameCacheEntry(hContact);
}
- if (!strcmp(cws->szModule, "Protocol")) {
- if (!strcmp(cws->szSetting, "p")) {
+ if (!mir_strcmp(cws->szModule, "Protocol")) {
+ if (!mir_strcmp(cws->szSetting, "p")) {
char *szProto;
if (cws->value.type == DBVT_DELETED)
szProto = NULL;
diff --git a/src/modules/clist/clisttray.cpp b/src/modules/clist/clisttray.cpp
index ffd8e0ae26..f6983cb912 100644
--- a/src/modules/clist/clisttray.cpp
+++ b/src/modules/clist/clisttray.cpp
@@ -695,7 +695,7 @@ INT_PTR fnTrayIconProcessMessage(WPARAM wParam, LPARAM lParam)
for (int j = 0; j < accounts.getCount(); j++) {
int k = cli.pfnGetAccountIndexByPos(j);
if (k >= 0) {
- if (!strcmp(cli.trayIcon[i].szProto, accounts[k]->szModuleName)) {
+ if (!mir_strcmp(cli.trayIcon[i].szProto, accounts[k]->szModuleName)) {
HMENU hm = GetSubMenu(hMenu, ind);
if (hm) hMenu = hm;
break;
@@ -799,7 +799,7 @@ int fnCListTrayNotify(MIRANDASYSTRAYNOTIFY* msn)
if (msn->szProto) {
for (int j = 0; j < cli.trayIconCount; j++) {
if (cli.trayIcon[j].szProto != NULL) {
- if (!strcmp(msn->szProto, cli.trayIcon[j].szProto)) {
+ if (!mir_strcmp(msn->szProto, cli.trayIcon[j].szProto)) {
iconId = cli.trayIcon[j].id;
break;
}
diff --git a/src/modules/clist/contacts.cpp b/src/modules/clist/contacts.cpp
index 7bb91e1cd7..2f04fe4c1e 100644
--- a/src/modules/clist/contacts.cpp
+++ b/src/modules/clist/contacts.cpp
@@ -42,7 +42,7 @@ BYTE nameOrder[NAMEORDERCOUNT];
static int GetDatabaseString(CONTACTINFO *ci, const char* setting, DBVARIANT* dbv)
{
- if (strcmp(ci->szProto, "CList") && CallProtoService(ci->szProto, PS_GETCAPS, PFLAGNUM_4, 0) & PF4_INFOSETTINGSVC) {
+ if (mir_strcmp(ci->szProto, "CList") && CallProtoService(ci->szProto, PS_GETCAPS, PFLAGNUM_4, 0) & PF4_INFOSETTINGSVC) {
DBCONTACTGETSETTING cgs = { ci->szProto, setting, dbv };
dbv->type = (ci->dwFlag & CNF_UNICODE) ? DBVT_WCHAR : DBVT_ASCIIZ;
diff --git a/src/modules/clist/clistmod.cpp b/src/modules/clist/clistmod.cpp
index 75d5014d63..1ab5fd2c8f 100644
--- a/src/modules/clist/clistmod.cpp
+++ b/src/modules/clist/clistmod.cpp
@@ -166,7 +166,7 @@ int fnIconFromStatusMode(const char *szProto, int status, MCONTACT)
if (szProto == NULL)
return index + 1;
for (i=0; i < protoIconIndex.getCount(); i++) {
- if (strcmp(szProto, protoIconIndex[i].szProto) == 0)
+ if (mir_strcmp(szProto, protoIconIndex[i].szProto) == 0)
return protoIconIndex[i].iIconBase + index;
}
return 1;
@@ -199,7 +199,7 @@ static void AddProtoIconIndex(PROTOACCOUNT *pa)
static void RemoveProtoIconIndex(PROTOACCOUNT *pa)
{
for (int i=0; i < protoIconIndex.getCount(); i++)
- if (strcmp(protoIconIndex[i].szProto, pa->szModuleName) == 0) {
+ if (mir_strcmp(protoIconIndex[i].szProto, pa->szModuleName) == 0) {
protoIconIndex.remove(i);
break;
}
@@ -438,7 +438,7 @@ static INT_PTR CompareContacts(WPARAM wParam, LPARAM lParam)
return 2 * (statusa == ID_STATUS_OFFLINE) - 1;
}
/* both are online, now check protocols */
- rc = strcmp(SAFESTRING(szProto1), SAFESTRING(szProto2)); /* strcmp() doesn't like NULL so feed in "" as needed */
+ rc = mir_strcmp(SAFESTRING(szProto1), SAFESTRING(szProto2)); /* mir_strcmp() doesn't like NULL so feed in "" as needed */
if (rc != 0 && (szProto1 != NULL && szProto2 != NULL))
return rc;
/* protocols are the same, order by display name */